@@ -8,7 +8,8 @@ from tests.cli_test_case import CliTestCase
 
 
 class PytestTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath('../data/pytest/').resolve()
+    test_files_dir = Path(__file__).parent.joinpath(
+        '../data/pytest/').resolve()
     result_file_path = test_files_dir.joinpath('record_test_result.json')
 
     @responses.activate
@@ -31,13 +32,14 @@ class PytestTest(CliTestCase):
                           'pytest', str(self.test_files_dir.joinpath("report.xml")))
 
         self.assertEqual(result.exit_code, 0)
-        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        payload = json.loads(gzip.decompress(
+            responses.calls[1].request.body).decode())
         expected = self.load_json_from_file(self.result_file_path)
         self.assert_json_orderless_equal(expected, payload)
 
     def setUp(self):
         super().setUp()
-        self.current_dir = os.getcwd();
+        self.current_dir = os.getcwd()
         os.chdir(str(self.test_files_dir))
 
     def tearDown(self):
